pub enum InterpreterError {
MultipleRead(NodeId),
MultipleWrite(NodeId),
SSAError(SSAError),
TypeError(EdgeId),
ArityError(EdgeId),
Load(EdgeId, Path),
ApplyError(EdgeId),
}Expand description
Evaluation errors
Variants
MultipleRead(NodeId)
A node appeared as a source of multiple hyperedges, and so interpreting tried to read a value that had already been consumed.
MultipleWrite(NodeId)
A node appeared as a target of multiple hyperedges, and so was written to multiple times during interpretation.
SSAError(SSAError)
A term could not be mapped into SSA form
TypeError(EdgeId)
Could not apply an operation because arguments were not of the correct form.
ArityError(EdgeId)
Unexpected number of arguments to an operation
Load(EdgeId, Path)
Interpreter failed to handle a Load operation
ApplyError(EdgeId)
Interpreter-specific error while trying to apply an op