Module stdlib

Module stdlib 

Standard library of declarations and definitions for catgrad’s lang category.

Modules

nn
ops

Traits

FnModule
A FnModule is a “Function Module”: a Module with a single output var. The call method is a helper for getting the single output of self.op.
Module
A type implementing Module defines a typed term with additional metadata. Analogous to a nn.Module in PyTorch. In total, a T: Module defines:

Functions

stdlib
Standard library declarations and definitions
to_load_ops
Convert parameter paths to Load operations with a given prefix