Standard library of declarations and definitions for catgrad’s lang category.
Modules
Traits
- FnModule
- A FnModule is a “Function Module”: a
Modulewith a single output var. Thecallmethod is a helper for getting the single output of self.op. - Module
- A type implementing
Moduledefines a typed term with additional metadata. Analogous to ann.Modulein PyTorch. In total, aT: Moduledefines:
Functions
- stdlib
- Standard library declarations and definitions
- to_
load_ ops - Convert parameter paths to Load operations with a given prefix